"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * This module imports the necessary functions and modules to run Jest tests.
 * @module Jest
 * @requires describe
 * @requires expect
 * @requires test
 */
const globals_1 = require("@jest/globals");
/**
 * Imports the CardNumberParse class from the cardNumber module.
 * @module cardNumber
 * @class CardNumberParse
 */
const cardNumber_1 = require("../cardNumber/cardNumber");
/**
 * Test suite for the Card component.
 */
(0, globals_1.describe)('Card', () => {
    /**
     * Tests the CardNumberParse function to ensure that it correctly parses a given card number string.
     * @returns None
     */
    (0, globals_1.test)('Pase CardNumber', () => {
        /**
         * Takes in a string of card number and removes any dashes or spaces.
         * @param {string} cardNumber - the card number to parse
         * @returns {string} - the parsed card number without any dashes or spaces
         * @example
         * // returns '1111222233334444'
         * CardNumberParse('1111-2222-3333-4444')
         */
        (0, globals_1.expect)((0, cardNumber_1.CardNumberParse)('1111-2222-3333-4444')).toStrictEqual('1111222233334444');
        /**
         * Takes in a string of card number and removes any spaces to return a string of only digits.
         * @param {string} cardNumber - the card number to parse
         * @returns {string} - the parsed card number with no spaces
         */
        (0, globals_1.expect)((0, cardNumber_1.CardNumberParse)('1111 2222 3333 4444')).toStrictEqual('1111222233334444');
        /**
         * Parses a string of card number and returns a string of only digits.
         * @param {string} cardNumber - the card number string to parse
         * @returns {string} - a string of only digits
         * @example
         * // returns '1111222233334444'
         * CardNumberParse('۱۱۱۱.۲۲۲۲.۳۳۳۳.۴۴۴۴')
         */
        (0, globals_1.expect)((0, cardNumber_1.CardNumberParse)('۱۱۱۱.۲۲۲۲.۳۳۳۳.۴۴۴۴')).toStrictEqual('1111222233334444');
    });
});
