"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const idNumber_1 = require("../idNumber");
/**
 * A test suite for the Card component.
 */
(0, globals_1.describe)('Card', () => {
    /**
     * Test function for the IdNumberFind function.
     * Tests if the function returns the correct province and city for a given Id Number.
     * @returns None
     */
    (0, globals_1.test)('Id Number city', () => {
        (0, globals_1.expect)((0, idNumber_1.IdNumberFind)('194')).toMatchObject({
            province: 'خوزستان',
            city: 'بندرماهشهر',
        });
    });
    /**
     * Tests the CheckIdNumber function to ensure that it correctly identifies valid ID numbers.
     * @returns None
     */
    (0, globals_1.test)('Id Number is valid', () => {
        /**
         * Checks if the given string is a valid Iranian national ID number.
         * @param {string} idNumber - The ID number to check.
         * @returns {boolean} - True if the ID number is valid, false otherwise.
         * @example
         * expect(CheckIdNumber('۱۲۳۴۵۶۷۸۹0')).toBeFalsy();
         */
        (0, globals_1.expect)((0, idNumber_1.CheckIdNumber)('۱۲۳۴۵۶۷۸۹0')).toBeFalsy();
        /**
         * Checks if the given ID number is valid.
         * @param {string} idNumber - The ID number to check.
         * @returns {boolean} - True if the ID number is valid, false otherwise.
         * @example
         * expect(CheckIdNumber('123۴۶۷۱۲11')).toBeFalsy();
         */
        (0, globals_1.expect)((0, idNumber_1.CheckIdNumber)('123۴۶۷۱۲11')).toBeFalsy();
        /**
         * Tests whether a given ID number is valid or not.
         * @param {string} idNumber - The ID number to be checked.
         * @returns {boolean} - Returns true if the ID number is valid, false otherwise.
         */
        (0, globals_1.expect)((0, idNumber_1.CheckIdNumber)('0054725112')).toBeFalsy();
    });
});
